//
//  RPSGameViewController.m
//  RPS2
//
//  Created by Edward Benson on 1/12/10.
//  Copyright 2010 MIT. All rights reserved.
//

#import "RPSGameViewController.h"
#import "NSString+RPS.h"
#import "AboutController.h"
#import "ASIFormDataRequest.h"

@implementation RPSGameViewController

@synthesize myMove, opponentMove, myName, opponentName;

-(id)init {
	if (self = [super init]) {
		self.title = @"Play";
		self.myName = @"Ted";
	}
	return self;
}

- (IBAction)makeMove:(id)sender {
	// Determine the move
	if (sender == rockButton) {
		self.myMove = @"rock";
	}
	else if (sender == paperButton) {
		self.myMove = @"paper";
	}
	else if (sender == scissorsButton) {
		self.myMove = @"scissors";
	}
	else {
		// Huh?
		return;
	}
	
	// Disable the buttons
	rockButton.enabled = NO;
	paperButton.enabled = NO;
	scissorsButton.enabled = NO;	
	
	// Set the label
	myMoveLabel.text = [[self.myMove capitalizedString] stringByAppendingFormat:@"!"];

	// Play the game remotely
	[self connectToServer];
}

- (IBAction)aboutClicked:(id)sender {
	AboutController *ac = [[[AboutController alloc] init] autorelease];
	UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:ac];
	[self presentModalViewController:nav animated:YES];
	[nav release];
}

-(void)connectToServer {
	NSString *urlString = [NSString stringWithFormat:@"http://iphonedev.csail.mit.edu/rps.php?player=%@&move=%@", 
						   self.myName, self.myMove];
	NSURL *url = [NSURL URLWithString:urlString];
	ASIFormDataRequest *request = [ASIFormDataRequest requestWithURL:url];
	[request setDelegate:self];
	[request startAsynchronous];
}

- (void)requestFinished:(ASIHTTPRequest *)request {
	// Fetch the PLIST as a String, then decode it into a Dictionary
	NSString *responseString = [request responseString];
	NSDictionary *responseDict = [responseString propertyList];

	// Fetch the data from the response
	self.opponentName = [responseDict objectForKey:@"opponent"];
	self.opponentMove = [responseDict objectForKey:@"opponentMove"];
	
	// Complete the game
	[self completeGame];
}

- (void)requestFailed:(ASIHTTPRequest *)request {
	NSError *error = [request error];
	
	UIAlertView *alert = [[UIAlertView alloc] 
						  initWithTitle:@"Could not Connect" 
						  message:@"The server was unreachable" 
						  delegate:nil 
						  cancelButtonTitle:@"OK" 
						  otherButtonTitles:nil];
	[alert show];
	[alert autorelease];
}

-(void)completeGame {
	// Show opponent move on screen
	opponentNameLabel.text = self.opponentName;
	opponentMoveLabel.text = [[self.opponentMove capitalizedString] stringByAppendingString:@"!"];
	
	// Show results on the screen
	if ([self.myMove rpsBeats:self.opponentMove]) {
		outcomeLabel.text = [NSString stringWithFormat:@"%@ wins!", self.myName];
	}
	else {
		outcomeLabel.text = [NSString stringWithFormat:@"%@ wins!", self.opponentName];
	}
	
	// Save the results to CoreData
	NSManagedObjectContext *context = [[[UIApplication sharedApplication] delegate] managedObjectContext];	
	NSManagedObject *savedGame = [NSEntityDescription insertNewObjectForEntityForName:@"SavedGame" 
												   inManagedObjectContext:context];
	[savedGame setValue:self.opponentName forKey:@"opponent"];
	[savedGame setValue:self.myMove forKey:@"myThrow"];
	[savedGame setValue:self.opponentMove forKey:@"theirThrow"];
	[savedGame setValue:[NSDate date] forKey:@"date"];

	[context save:nil];
}

- (IBAction)resetGameClicked {
	UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Really?" 
													message:@"Really reset?" 
												   delegate:self 
										  cancelButtonTitle:@"No" 
										  otherButtonTitles:@"Yes", nil];
	[alert show];
	[alert release];
}

- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex {
	if (buttonIndex == 1) {
		[self resetGame];
	}
}

-(IBAction)resetGame {
	outcomeLabel.text = nil;
	myMoveLabel.text = nil;
	opponentMoveLabel.text = nil;
	opponentNameLabel.text = @"Player 2";
	
	rockButton.enabled = YES;
	paperButton.enabled = YES;
	scissorsButton.enabled = YES;	
}


/*
 // The designated initializer.  Override if you create the controller programmatically and want to perform customization that is not appropriate for viewDidLoad.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if (self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil]) {
        // Custom initialization
    }
    return self;
}
*/


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
	myNameLabel.text = self.myName;
}

/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}

- (void)dealloc {
	[myMove release];
	[opponentMove release];
	
	[myName release];
	[opponentName release];
	
    [super dealloc];
}


@end
